"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HandlerContainer = exports.MessageHandlerConfigBuilder = exports.MessageHandlerConfig = void 0;
class MessageHandlerConfig {
    schema;
    handler;
    constructor(schema, handler) {
        this.schema = schema;
        this.handler = handler;
    }
}
exports.MessageHandlerConfig = MessageHandlerConfig;
class MessageHandlerConfigBuilder {
    configs;
    constructor() {
        this.configs = [];
    }
    addConfig(schema, handler) {
        // @ts-ignore
        this.configs.push(new MessageHandlerConfig(schema, handler));
        return this;
    }
    build() {
        return this.configs;
    }
}
exports.MessageHandlerConfigBuilder = MessageHandlerConfigBuilder;
class HandlerContainer {
    messageHandlers;
    messageTypeField;
    constructor(options) {
        this.messageTypeField = options.messageTypeField;
        this.messageHandlers = this.resolveHandlerMap(options.messageHandlers);
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    resolveHandler(messageType) {
        const handler = this.messageHandlers[messageType];
        if (!handler) {
            throw new Error(`Unsupported message type: ${messageType}`);
        }
        return handler;
    }
    resolveHandlerMap(supportedHandlers) {
        return supportedHandlers.reduce((acc, entry) => {
            // @ts-ignore
            const messageType = entry.schema.shape[this.messageTypeField].value;
            acc[messageType] = entry.handler;
            return acc;
        }, {});
    }
}
exports.HandlerContainer = HandlerContainer;
//# sourceMappingURL=HandlerContainer.js.map